Output and render functions for using cron editor within 'shiny' applications and interactive 'rmarkdown' documents.
cronOutput(
outputId,
label = NULL,
language = "en-US",
width = "100%",
height = NULL
)renderCron(expr, env = parent.frame(), quoted = FALSE)
An 'htmlwidgets' object for use in a shiny app, containing a placeholder for where the cron input element is rendered.
A 'htmlwidgets' object for use in a 'shiny' app as an input element
output variable to read from
The label to show, just like in a regular Shiny input element. Set to NULL if you don't want a label.
The language the cron editor's UI will be in. Choose one of en-US, nl-NL, es-ES, zh-CN. Note that if you have multiple cron editors on one page, the last editor's language will be the one for all editors.
Must be a valid CSS unit (like '100%',
'400px', 'auto') or a number, which will be coerced to a
string and have 'px' appended.
An expression that generates a test
The environment in which to evaluate expr.
Is expr a quoted expression (with quote())? This
is useful if you want to save an expression in a variable.